"use server"

import prisma from "@/lib/prisma";

export async function getBreadcrumbLabels(path: string) {
  const segments = path.split("/").filter(Boolean)

  const breadcrumbs: { label: string; href: string; icon: string }[] = [
    { label: "Home", href: "/", icon: "home" }
  ]

  let base = ""
  let i = 0

  while (i < segments.length) {
    const segment = segments[i]

    switch (segment) {
      case "galleries": {
        const gallerySlug = segments[i + 1]
        const gallery = await prisma.gallery.findUnique({ where: { slug: gallerySlug } })

        if (gallery) {
          base += `/galleries/${gallerySlug}`
          breadcrumbs.push({
            label: gallery.name,
            href: base,
            icon: "gallery"
          })

          // Check if there's an album
          const albumSlug = segments[i + 2]
          if (albumSlug) {
            const album = await prisma.album.findFirst({
              where: { slug: albumSlug, galleryId: gallery.id }
            })
            if (album) {
              base += `/${albumSlug}`
              breadcrumbs.push({
                label: album.name,
                href: base,
                icon: "album"
              })

              // Check for image ID
              const imageId = segments[i + 3]
              if (imageId) {
                const image = await prisma.image.findUnique({
                  where: { id: imageId }
                })
                if (image) {
                  base += `/${imageId}`
                  breadcrumbs.push({
                    label: image.imageName,
                    href: base,
                    icon: "image"
                  })
                }
              }
            }
          }
        }
        i += 4
        break
      }

      case "artists": {
        const slug = segments[i + 1]
        const artist = await prisma.artist.findUnique({ where: { slug } })
        if (artist) {
          base += `/artists/${slug}`
          breadcrumbs.push({
            label: artist.displayName,
            href: base,
            icon: "artist"
          })
        }
        i += 2
        break
      }

      case "categories": {
        const id = segments[i + 1]
        const category = await prisma.category.findUnique({ where: { id } })
        if (category) {
          base += `/categories/${id}`
          breadcrumbs.push({
            label: category.name,
            href: base,
            icon: "category"
          })
        }
        i += 2
        break
      }

      case "tags": {
        const id = segments[i + 1]
        const tag = await prisma.tag.findUnique({ where: { id } })
        if (tag) {
          base += `/tags/${id}`
          breadcrumbs.push({
            label: tag.name,
            href: base,
            icon: "tag"
          })
        }
        i += 2
        break
      }

      case "about": {
        base += `/about`
        breadcrumbs.push({
          label: "About",
          href: base,
          icon: "about"
        })
        i++
        break
      }

      default:
        i++
        break
    }
  }

  return breadcrumbs
}
