import ImageCard from "@/components/cards/ImageCard";
import ArtistInfoBox from "@/components/images/ArtistInfoBox";
import ImageMetadataBox from "@/components/images/ImageMetadataBox";
import prisma from "@/lib/prisma";

export default async function ImagePage({ params }: { params: { gallerySlug: string, albumSlug: string, imageId: string } }) {
  const { imageId } = await params;

  const image = await prisma.image.findUnique({
    where: {
      id: imageId
    },
    include: {
      artist: {
        include: { socials: { where: { isVisible: true }, orderBy: [{ sortIndex: 'asc' }, { isPrimary: "desc" }] } }
      },
      colors: { include: { color: true } },
      album: { include: { gallery: true } },
      categories: true,
      tags: true,
      variants: true,
      metadata: true,
      stats: true
    }
  })

  if (!image) return <div>Image not found</div>

  return (
    <div>
      <div className="flex flex-col items-center">
        <div>
          <h1 className="text-2xl font-bold mb-4 pb-8">{image.imageName}</h1>
        </div>
        <ImageCard image={image} gallerySlug={image.album?.gallery?.slug} albumSlug={image.album?.slug} size="large" />
        <section className="py-8 flex flex-col gap-4">
          {image.artist && <ArtistInfoBox artist={image.artist} />}
          <ImageMetadataBox
            album={image.album}
            categories={image.categories}
            tags={image.tags}
            creationDate={image.creationDate}
            creationYear={image.creationYear}
            creationMonth={image.creationMonth}
            altText={image.altText}
            description={image.description}
          />
        </section>
      </div>
    </div >
  );
}