import { Artist } from "@/generated/prisma";
import { getSocialIcon } from "@/utils/socialIconMap";
import { LinkIcon } from "lucide-react";

type Props = {
  artist: Artist & {
    socials: {
      id: string;
      handle: string;
      platform: string;
      link: string | null;
      isPrimary: boolean;
    }[];
  };
};

export default function ArtistInfoBox({ artist }: Props) {
  return (
    <div className="border rounded-lg p-4 shadow bg-muted/30 w-full max-w-xl flex flex-col items-center text-center">
      <h1 className="text-3xl font-bold">Socials / Links</h1>
      <div className="mt-4 flex flex-col flex-wrap gap-4 items-center">
        {artist.socials.map((social) => {
          const Icon = getSocialIcon(social.platform) ?? LinkIcon;
          return (
            <div key={social.id} className="">
              <a
                href={social.link || "#"}
                className="flex items-center gap-2 text-sm text-muted-foreground hover:text-primary"
                target="_blank" rel="noopener noreferrer"
              >
                <Icon className="h-4 w-4" />
                {social.platform}: {social.handle}
              </a>
            </div>
          );
        })}
      </div>
    </div>
  );
}
