import { cn } from "@/lib/utils"
import { HTMLAttributes, ReactNode } from "react"
import { Badge } from "../ui/badge"

interface TagBadgeProps extends HTMLAttributes<HTMLDivElement> {
  label: string
  icon?: ReactNode
  variant?: "default" | "secondary" | "outline" | "destructive" | null
  hidden?: boolean
}

export function TagBadge({
  label,
  icon,
  variant = "default",
  hidden = false,
  className,
  ...props
}: TagBadgeProps) {
  if (hidden) return null

  return (
    <Badge
      variant={variant}
      className={cn("inline-flex items-center text-xs px-2 py-0.5 rounded-md", className)}
      {...props}
    >
      {icon}
      {label}
    </Badge>
  )
}
