import { Album, Color, Image, ImageColor } from "@/generated/prisma";
import CoverCard from "../cards/CoverCard";

type AlbumsWithCover = (Album & {
  coverImage: (Image & {
    colors?: (ImageColor & { color: Color })[];
  }) | null;
})[];

export default function AlbumList({
  albums,
  gallerySlug,
}: {
  albums: AlbumsWithCover;
  gallerySlug: string;
}) {
  if (!albums.length) return <p>There are no albums here!</p>;

  return (
    <section>
      <div className="grid gap-6 sm:grid-cols-2 md:grid-cols-3 xl:grid-cols-4">
        {albums.map((album) => (
          <CoverCard
            key={album.id}
            item={{
              id: album.id,
              name: album.name,
              slug: album.slug,
              coverImage: album.coverImage ?? undefined,
              type: "album",
              gallerySlug,
            }}
          />
        ))}
      </div>
    </section>
  );
}
